********************************************************************************
*** Author names: Vera Eichenauer, Andreas Fuchs, Sven Kunze, Eric Strobl 
*** Distortions in Aid Allocation of United Nations Flash Appeals: Evidence from the 2015 Nepal Earthquake
*** This do-file contains the regression analysis
*** Finalized on March 21, 2020
*******************************************************************************
set more off, perm
clear all
set matsize 6000
drop _all	


* Create folder to store regression results
cap mkdir replication

* Open log file
cap log using "replication\Eichenauer_et_al_WD.log", replace

*******************************************************************************************************************************************
**  Analysis
*******************************************************************************************************************************************
use "UN_Flash_Appeals_replication_data.dta", clear	

********************************
* Descriptive statistics	
********************************
reg  N4   	N4funded damage_immediate_high
	estpost sum N4 N4funded appealaid_des appealaid_req_des  obtainsh genaid_p popn2011 ///
			 dist_ktm dist_airport mean_rain_1998_2014 damage_immediate_high damage_after_high  ///
			 avNTL_pre pc_solidfound pc_privilcastes pc_hindu pc_congress  pc_communist affected_1988  ///
			 Urban area_geo projectVDC_d  if e(sample), detail /*to view on screen */
		
esttab  using replication\Descriptives_replication.xls , cells("varlabels(`e(labels)') count mean sd min max ")  /* sfmt(fmt [%4.2f])*/ title("Descriptives for national sample") ///
	noobs tab label replace /* for export */
	
********************************
* Appendix 7: Correlation matrix	
********************************	
reg  N4  N4funded damage_immediate_high
	estpost corr  damage_immediate_high damage_after_high lnpop lnarea mean_rain_1998_2014   lnavNTL_pre pc_solidfound lndist_ktm ///
	lndist_airport affected_1988 genaid_p pc_privilcastes pc_hindu pc_communist pc_congress	 if e(sample) , matrix
	esttab using  "replication\Appendix 7.xls" , label /*cells(rho(fmt(2)))*/ tab unstack not nostar noobs  replace /* for export */
	
	
********************************
* Define control variables
********************************

* Disaster impact variables
global damage damage_immediate_high damage_after_high 

* Socio-economic vulnerabilitiy
global soc_oec lnpop  pc_solidfound lnavNTL_pre 

* Physical vulnerabilities
global physical lnarea mean_rain_1998_2014 mean_rain2_1998_2014 lndist_ktm lndist_airport affected_1988

* Existing aid networks
global aid genaid_p

* Ethnic, religious and political interests
global ethn pc_privilcastes 
global rel pc_hindu 
global pol pc_communist pc_congress	
	
************************************************************************************************************************************************	
** Main Tables
************************************************************************************************************************************************

**********************************************	
* Table 3
**********************************************

nbreg N4  $damage $soc_oec $physical  $aid    , vce(cluster id_adm3)				
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Prop. project number"			

nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"
	
* Compute sample std dev to create Figure 5
sum $damage $soc_oec $physical  $aid    $ethn $rel $pol if e(sample)	

eststo: reg lnappealaid_req  $damage $soc_oec $aid  $physical   , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"		
	qui estadd local method="OLS"				
	
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"
	
test pc_communist=pc_congress	
	
estout _all using "replication/Table3.xls", replace  label   noabbrev wrap  ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Table 3 paper, cross-section at the 4th administrative level") drop (_cons)    ///
			stats(DV method r2_a N N_clust, labels("Dependent variable" "Method" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all		


**********************************************	
* Table 4
**********************************************

nbreg N4funded   $damage $soc_oec $physical  $aid    $ethn $rel $pol , vce(cluster id_adm3)					
eststo:	margins, dydx(*)	post atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"			

eststo: reg lnappealaid  $damage $soc_oec $physical  $aid     $ethn $rel $pol  , vce(cluster id_adm3)				
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"	
	
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"		
	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol  , vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				
	
estout _all using "replication/Table4.xls", replace  label   noabbrev wrap  drop(_cons) ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Table 4 paper, cross-section at the 4th administrative level")    ///
			stats(DV method r2_a N N_clust, labels("Dependent variable" "Method" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes:  Results in columns 1 and 2 are estimated with NB regression and columns 3 and 4 with OLS. Columns 1 and 2 show marginal effects at the mean. Robust standard errors (in brackets) are clustered at the district level (ADM3). * (**, ***) indicates statistical significance at the ten-percent (five-percent, one-percent) level.")
	estimates drop _all			
	

************************************************************************************************************************************************	
** Appendices 
************************************************************************************************************************************************

**********************************************	
* Appendix 8
**********************************************	

* Baseline: Table 3, column 2
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"			
	
* Without Kathmandu	
	preserve
	drop if name_adm3=="Kathmandu" 
nbreg N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol  , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Prop. project number"	
	qui estadd local Note="Without Kathmandu"	
	restore

* Include ADM2 FE
nbreg N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol  i.id_adm2, vce(cluster id_adm3)					
eststo: margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Prop. project number"		
	qui estadd local Note="ADM2 FE"	

	*******
	
* Baseline Table 3, col. 4	
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"
	
* Without Kathmandu	
	preserve
	drop if name_adm3=="Kathmandu" 
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"
	qui estadd local Note="Without Kathmandu"		
	restore
	
* Include ADM2 FE	
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol  i.id_adm2, vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"
	qui estadd local Note="ADM2 FE"	
	
estout _all using "replication/Appendix 8.xls", replace  label   noabbrev wrap  ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Appendix 8, based on Table 3, without Kathmandu & ADM2 fixed effects") drop (_cons *adm2*)    ///
			stats(DV method Note r2_a N N_clust, labels("Dependent variable" "Note" "Method" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all	

**********************************************	
* Appendix 9
**********************************************	
* Baseline Table 4, col. 3
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"		

* Without Kathmandu		
	preserve
	drop if name_adm3=="Kathmandu"
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"	
	qui estadd local Note="Without Kathmandu"		
	restore
	
* Include ADM2 FE
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol i.id_adm2, vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"	
	qui estadd local Note="ADM2 FE"	
	
	*******
* Baseline Table 4, col. 4
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol  , vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		

* Without Kathmandu	
	preserve
	drop if name_adm3=="Kathmandu"
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol  , vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	qui estadd local Note="Without Kathmandu"		
	restore
	
* Include ADM2 FE	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol i.id_adm2 , vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"	
	qui estadd local Note="ADM2 FE"	
	
	*******
* Baseline Table 4, col. 5	
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				

* Without Kathmandu	
	preserve
	drop if name_adm3=="Kathmandu"
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"		
	qui estadd local Note="Without Kathmandu"		
	restore
	
* Include ADM2 FE
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol i.id_adm2 if projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"	
	qui estadd local Note="ADM2 FE"	

estout _all using "replication/Appendix 9.xls", replace  label   noabbrev wrap  drop(_cons *adm2*) ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Appendix 13, based on Table 4, without Kathmandu & ADM2 fixed effects")    ///
			stats(DV method Note r2_a N N_clust, labels("Dependent variable" "Method" "Note" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all		

	
	
**********************************************	
* Appendix 10: 50km buffer around Kathmandu
**********************************************	

* Baseline: Table 3, column 2
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"			
	
* <50km from KTM		
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol if buffer_50k_ktm==1 , vce(cluster id_adm3) 
eststo:	margins, dydx(*) post 	atmeans
*eststo: reg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol if buffer_50k_ktm==1 , vce(cluster id_adm3)					
	qui estadd local method="OLS"				
	qui estadd local DV="Prop. project number"		
	qui estadd local Note="<50km from KTM"		

* >50km from KTM	
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol if buffer_50k_ktm==0 , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"		
	qui estadd local Note=">50km from KTM"		

	*******
* Baseline Table 3, col. 4		
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"				
	qui estadd local Note="Baseline"	
	
* <50km from KTM	
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol if buffer_50k_ktm==1 , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"				
	qui estadd local Note="<50km from KTM"		

* >50km from KTM
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol if buffer_50k_ktm==0 , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"	
	qui estadd local Note=">50km from KTM"

	
estout _all using "replication/Appendix 10.xls", replace  label   noabbrev wrap  ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Appendix 10, based on Table 3, 50km buffer around Kathmandu") drop (_cons)    ///
			stats(DV method Note r2_a N N_clust, labels("Dependent variable" "Method" "Note" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all	

**********************************************	
* Appendix 11: 50km buffer around Kathmandu
**********************************************	
* Baseline Table 4, col. 3
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"		

* <50km from KTM	
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol if buffer_50k_ktm==1, vce(cluster id_adm3)	
eststo: margins, dydx(*) post	atmeans 
	qui estadd local method="OLS"			
	qui estadd local DV="Funded project number"		
	qui estadd local Note="<50km from KTM"		
	
* >50km from KTM	
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol if buffer_50k_ktm==0, vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"			
	qui estadd local Note=">50km from KTM"			
	
	*******
* Baseline Table 4, col. 4	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	qui estadd local Note="Baseline"		
	
* <50km from KTM		
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol  if buffer_50k_ktm==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	qui estadd local Note="<50km from KTM"		
	
* >50km from KTM	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol  if buffer_50k_ktm==0, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	qui estadd local Note=">50km from KTM"			
	
	*******	
* Baseline Table 4, col. 5		
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				
	qui estadd local Note="Baseline"	
	
* <50km from KTM		
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1 & buffer_50k_ktm==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				
	qui estadd local Note="<50km from KTM"		
	
* >50km from KTM	
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1 & buffer_50k_ktm==0, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"		
	qui estadd local Note=">50km from KTM"		

estout _all using "replication/Appendix 11.xls", replace  label   noabbrev wrap  drop(_cons) ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Appendix 11, based on Table 4, 50km Buffer around Kathmandu")    ///
			stats(DV method Note r2_a N N_clust, labels("Dependent variable" "Method" "Note" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all			
	
**********************************************	
* Appendix 12: urban / rural
**********************************************	

* Baseline: Table 3, column 2
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"	
	
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol if Urban==1 , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"	
	qui estadd local Note="Urban"	
	
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol  if Urban==0 , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"		
	qui estadd local Note="Rural"	

	*******
* Baseline Table 3, col. 4		
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"				
	qui estadd local Note="Baseline"
	
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol if Urban==1, vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"				
	qui estadd local Note="Urban"	
	
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol  if Urban==0, vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"				
	qui estadd local Note="Rural"	
	
estout _all using "replication/Appendix 12.xls", replace  label   noabbrev wrap  ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Appendix 12, based on Table 3, urban vs. rural") drop (_cons)    ///
			stats(DV method Note r2_a N N_clust, labels("Dependent variable" "Method" "Note" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all	

	
**********************************************	
* Appendix 13: urban / rural
**********************************************	
* Baseline Table 4, col. 3
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"	
	
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol if Urban==1, vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"		
	qui estadd local Note="Urban"	
	
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol  if Urban==0, vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"			
	qui estadd local Note="Rural"	
	
	*******
* Baseline Table 4, col. 4	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	qui estadd local Note="Baseline"
	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol if Urban==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	qui estadd local Note="Urban"	
	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol  if Urban==0, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	qui estadd local Note="Rural"	
	
	*******	
* Baseline Table 4, col. 5		
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				
	qui estadd local Note="Baseline"	
	
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if  Urban==1 & projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				
	qui estadd local Note="Urban"	
	
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if Urban==0 & projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				
	qui estadd local Note="Rural"	
	

estout _all using "replication/Appendix 13.xls", replace  label   noabbrev wrap  drop(_cons) ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Appendix 13, based on Table 4, urban vs. rural")    ///
			stats(DV method Note r2_a N N_clust, labels("Dependent variable" "Method" "Note" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all			
	
	
**********************************************	
* Appendix 14: cluster ADM2 level
**********************************************	

* Baseline: Table 3, column 2
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm3)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"				
	qui estadd local Note="Baseline"
	
nbreg N4  $damage $soc_oec $physical  $aid    $ethn $rel $pol  , vce(cluster id_adm2)					
eststo:	margins, dydx(*) post 	atmeans
	qui estadd local method="NBREG"				
	qui estadd local DV="Prop. project number"				

	*******
* Baseline Table 3, col. 4		
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol , vce(cluster id_adm3)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"				
	qui estadd local Note="Baseline"	
	
eststo: reg lnappealaid_req  $damage $soc_oec $physical  $aid    $ethn $rel $pol , vce(cluster id_adm2)					
	qui estadd local DV="Requested appeal aid (ln)"			
	qui estadd local method="OLS"				
	
estout _all using "replication/Appendix 14.xls", replace  label   noabbrev wrap  ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Appendix 14, based on Table 4, cluster ADM2") drop (_cons)    ///
			stats(DV method Note r2_a N N_clust, labels("Dependent variable" "Method" "Note" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all	

**********************************************	
* Appendix 15:  cluster ADM2 level
**********************************************	
* Baseline Table 4, col. 3
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"		
	qui estadd local Note="Baseline"	
	
* Baseline Table 4, col. 3
nbreg N4funded   N4  $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm2)					
eststo: margins, dydx(*) post	atmeans
	qui estadd local method="NBREG"			
	qui estadd local DV="Funded project number"		
	
	*******
* Baseline Table 4, col. 4	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"		
	qui estadd local Note="Baseline"	
	
eststo: reg lnappealaid lnappealaid_req $damage $soc_oec $physical  $aid     $ethn $rel $pol , vce(cluster id_adm2)					
	qui estadd local method="OLS"			
	qui estadd local DV="Received appeal aid (ln)"	
	
	*******	
* Baseline Table 4, col. 5		
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1, vce(cluster id_adm3)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				
	qui estadd local Note="Baseline"	
	
eststo: reg obtainsh $damage $soc_oec $physical  $aid     $ethn $rel $pol  if projectVDC_d==1, vce(cluster id_adm2)					
	qui estadd local method="OLS"			
	qui estadd local DV="Share of obtained funding"				

estout _all using "replication/Appendix 15.xls", replace  label   noabbrev wrap  drop(_cons) ///
			cells(b(star fmt(%9.3f) label(Coef.)) se(fmt(3) par([ ]) label(Std. err.))) style(tab) starlevels(* 0.1 ** 0.05 *** 0.01) ///
			title("Appendix 15, based on Table 4, cluster AMD2")    ///
			stats(DV method Note r2_a N N_clust, labels("Dependent variable" "Method" "Note" "Adjusted R-squared" "N of observations" "N of clusters" ) fmt(3))  ///
			note("Notes: Robust standard errors in brackets, clustered at the third administrative level.")
	estimates drop _all					
	

*********************************************************************		
* Appendix 16: 	Interaction (ethnicity * disaster intensity)
*********************************************************************		

* Baseline: Table 3, column 2

* Marginal effects for immediate earthquake damage	
nbreg N4  $damage $soc_oec $physical  $aid    $rel $pol $ethn c.pc_privilcastes#c.damage_immediate_high c.pc_privilcastes#c.damage_after_high, vce(cluster id_adm3)
eststo: margins, dydx(pc_privilcastes) at(damage_immediate_high=(0 (0.05) 1)) atmeans post
marginsplot, level(90) yline(0) ytitle("Marginal effect of privileged caste", margin(medium)) ///
				title("Panel (a)") ///
				 xtitle("Immediate damage", margin(medium)) 	///
				graphregion(color(white))	scheme(s1color)
		graph save "replication/appendix16_column2_margins_immediate.gph", replace
		graph export   "replication/appendix16_column2_margins_immediate.pdf", replace	
		
* Marginal effects for aftershock  damage	
nbreg N4  $damage $soc_oec $physical  $aid    $rel $pol $ethn c.pc_privilcastes#c.damage_immediate_high c.pc_privilcastes#c.damage_after_high, vce(cluster id_adm3)
eststo: margins, dydx(pc_privilcastes) at(damage_after_high=(0 (0.05) 1)) atmeans post
marginsplot, level(90) yline(0) ytitle("Marginal effect of privileged caste", margin(medium)) ///
				title("Panel (b)") ///
				 xtitle("Aftershock damage", margin(medium)) 	///
				graphregion(color(white))	scheme(s1color)
		graph save "replication/appendix16_column2_margins_after.gph", replace
		graph export   "replication/appendix16_column2_margins_after.pdf", replace			

/*
* Baseline: Table 3, column 4		
nbreg N4  $damage $soc_oec $physical  $aid    $rel $pol $ethn c.pc_privilcastes#c.damage_immediate_high c.pc_privilcastes#c.damage_after_high, vce(cluster id_adm3) 
eststo: margins, dydx(pc_privilcastes) at(damage_immediate_high=(0 (0.05) 1)) atmeans post
qui estadd local method="NBREG" 
qui estadd local DV="Prop. project number" 

marginsplot, level(90) yline(0) ytitle("Marginal effect of privileged caste", margin(medium)) ///
				title("Panel (c)") ///
				 xtitle("Immediate damage", margin(medium)) 	///
				graphregion(color(white))	scheme(s1color)
		graph save "replication/appendix16_column4_margins_immediate.gph", replace
		graph export   "replication/appendix16_column4_margins_immediate.pdf", replace

***

nbreg N4  $damage $soc_oec $physical  $aid    $rel $pol $ethn c.pc_privilcastes#c.damage_immediate_high c.pc_privilcastes#c.damage_after_high, vce(cluster id_adm3) 
eststo: margins, dydx(pc_privilcastes) at(damage_after_high=(0 (0.05) 1)) atmeans post
qui estadd local method="NBREG" 
qui estadd local DV="Prop. project number" 

marginsplot, level(90) yline(0)ytitle("Marginal effect of privileged caste", margin(medium)) ///
				title("Panel (d)") ///
				 xtitle("Aftershock damage", margin(medium)) 	///
				graphregion(color(white)) scheme(s1color)
		graph save "replication/appendix16_column4_margins_after.gph", replace
		graph export   "replication/appendix16_column4_margins_after.pdf", replace

*/	
* Baseline: Table 3, column 4	
eststo: reg lnappealaid_req  $damage $soc_oec $aid  $physical  c.pc_privilcastes#c.damage_immediate_high c.pc_privilcastes#c.damage_after_high , vce(cluster id_adm3)						
margins, dydx(pc_privilcastes) at(damage_immediate_high=(0 (0.05) 1)) atmeans post
marginsplot, level(90) yline(0) ytitle("Marginal effect of privileged caste", margin(medium)) ///
				title("Panel (c)") ///
				 xtitle("Immediate damage", margin(medium)) 	///
				graphregion(color(white))	scheme(s1color)
		graph save "replication/appendix16_column4_margins_immediate.gph", replace
		graph export   "replication/appendix16_column4_margins_immediate.pdf", replace
		
***		
eststo: reg lnappealaid_req  $damage $soc_oec $aid  $physical  c.pc_privilcastes#c.damage_immediate_high c.pc_privilcastes#c.damage_after_high , vce(cluster id_adm3)					
margins, dydx(pc_privilcastes) at(damage_after_high=(0 (0.05) 1)) atmeans post 
marginsplot, level(90) yline(0)ytitle("Marginal effect of privileged caste", margin(medium)) ///
				title("Panel (d)") ///
				 xtitle("Aftershock damage", margin(medium)) 	///
				graphregion(color(white)) scheme(s1color)
		graph save "replication/appendix16_column4_margins_after.gph", replace
		graph export   "replication/appendix16_column4_margins_after.pdf", replace
		
		
* combine these figures
graph combine "replication/appendix16_column2_margins_immediate.gph" "replication/appendix16_column2_margins_after.gph" ///
				"replication/appendix16_column4_margins_immediate.gph" "replication/appendix16_column4_margins_after.gph" , ///
				ycommon iscale(0.5)  scheme(s1color)
graph save "replication/combfigure_appendix16.gph", replace 
	graph export   "replication/combfig_appendix16.pdf", replace			
		
cap log close
	